@@ -26,7 +26,7 @@ class AsyncTendermintAPI(BaseAsyncAPI):
         """Fetches the validator set for a height. If no height is given, defaults to latest.
 
         Args:
-            height (Optional[int], optional): block height. Defaults to None.
+            height (Optional[int], optional): block height.
 
         Returns:
             dict: validator set
@@ -38,7 +38,7 @@ class AsyncTendermintAPI(BaseAsyncAPI):
         """Fetches the block information for a given height. If no height is given, defaults to latest block.
 
         Args:
-            height (Optional[int], optional): block height. Defaults to None.
+            height (Optional[int], optional): block height.
 
         Returns:
             dict: block info
